@@ -66,7 +66,9 @@ const char *hide_strings[] = {
     /* ccTLDs */
     "Access to CCTLD WHOIS information is provided", "",	/* Afilias */
     "Access to ASNIC", "by this policy.",			/* as */
-    "% The WHOIS service offered", "% of the database",		/* eu */
+    "% The WHOIS service offered by DNS.be", "% protect the privacy", /* be */
+    "% The WHOIS service offered by EURid", "% of the database", /* eu */
+    "% WHOIS LEGAL STATEMENT AND TERMS & CONDITIONS", "",	/* sx */
     "NeuStar, Inc., the Registry", "OF THE AVAILABILITY",	/* us */
 
     NULL, NULL
