@@ -13,7 +13,7 @@ while (<>) {
 		(my ($a, $b) = /^([\w\d\.-]+)\s+([\w\d\.:-]+|[A-Z]+\s+.*)$/);
 
 	$b =~ s/^W(?:EB)?\s+/\\x01/;
-	$b =~ s/^VERISIGN\s+/\\x04/;
+	$b =~ s/^VERISIGN\s+/\\x04" "/;
 	$b = "\\x03" if $b eq 'NONE';
 	$b = "\\x08" if $b eq 'AFILIAS';
 	$b = "\\x0C" if $b eq 'ARPA';
